@@ -6,7 +6,9 @@
 
 #define MAX_METERS 32
 
-extern SDL_Surface *screen;
+#define SCREEN_BPP 32
+
+extern SDL_Surface *screen, *background_image;
 extern SDL_Surface *image, *meter, *meter_buf;
 extern SDL_Rect win, buf_rect[MAX_METERS], dest[MAX_METERS];
 
@@ -16,8 +18,11 @@ extern jack_port_t *output_ports[MAX_METERS];
 extern int num_meters;
 extern int num_scopes;
 extern int meter_freeze;
+extern int open_gl;
 extern float env[MAX_METERS];
 
 extern float bias;
 
+void get_cols_rows(int *c, int *r);
+
 #endif
